@@ -50,8 +50,26 @@ class ListInstanceIndicesRequest(RoaRequest):
 	def set_isManaged(self,isManaged):
 		self.add_query_param('isManaged',isManaged)
 
+	def get_size(self):
+		return self.get_query_params().get('size')
+
+	def set_size(self,size):
+		self.add_query_param('size',size)
+
 	def get_name(self):
 		return self.get_query_params().get('name')
 
 	def set_name(self,name):
-		self.add_query_param('name',name)
\ No newline at end of file
+		self.add_query_param('name',name)
+
+	def get_page(self):
+		return self.get_query_params().get('page')
+
+	def set_page(self,page):
+		self.add_query_param('page',page)
+
+	def get_isOpenstore(self):
+		return self.get_query_params().get('isOpenstore')
+
+	def set_isOpenstore(self,isOpenstore):
+		self.add_query_param('isOpenstore',isOpenstore)
\ No newline at end of file
