@@ -48,4 +48,10 @@ class UpdateInstanceRequest(RoaRequest):
 		return self.get_query_params().get('clientToken')
 
 	def set_clientToken(self,clientToken):
-		self.add_query_param('clientToken',clientToken)
\ No newline at end of file
+		self.add_query_param('clientToken',clientToken)
+
+	def get_orderActionType(self):
+		return self.get_query_params().get('orderActionType')
+
+	def set_orderActionType(self,orderActionType):
+		self.add_query_param('orderActionType',orderActionType)
\ No newline at end of file
